@@ -16,7 +16,7 @@ def validate_dates_before_after(intermediate_participant_path, date_in_study):
     date_folder_path = intermediate_participant_path + sep + date_in_study
     target_date_log_paths = sorted(glob(os.path.join(date_folder_path, target_file_pattern)))  # file name
     if len(target_date_log_paths) == 0:
-        print("No battery daily file on {}".format(date_in_study))
+        print("No daily report file on {}".format(date_in_study))
     else:
 
         # 1 day before target date
@@ -93,15 +93,15 @@ def match_feature(prompt_local_datetime_series, df_logs_combined):
         else:
             prompt_date = prompt_feature_df['Prompt_Date_Datetime'][idx] - timedelta(days=1)
 
-        df_logs_combined = df_logs_combined[df_logs_combined['Date'] == prompt_date]
+        df_logs_combined_filtered = df_logs_combined[df_logs_combined['Date'] == prompt_date]
 
         if df_logs_combined.shape[0] == 0:
             waking_hour = np.nan
             sleep_hour = np.nan
             print("No wake and sleep hour found for {}".format(prompt_date))
         else:
-            waking_hour = list(df_logs_combined["current_wake_time"])[0]
-            sleep_hour = list(df_logs_combined["current_sleep_time"])[0]
+            waking_hour = list(df_logs_combined_filtered["current_wake_time"])[0]
+            sleep_hour = list(df_logs_combined_filtered["current_sleep_time"])[0]
 
         matched_waking_hours_list.append(waking_hour)
         matched_sleep_hours_list.append(sleep_hour)
